@@ -3,13 +3,14 @@
 osm <- function(country, var, path, proxy=FALSE, ...) {
 	stopifnot(var %in% c("places", "highways", "railway"))
 	iso <- .getCountryISO(country)
-	.check_path(path)
+	path <- .get_path(path)
 
 	filename <- paste0(iso, "_", var, ".gpkg")
 	filepath <- file.path(path, filename)
 
 	if (!(file.exists(filepath))) {
-		url <- paste0(.data_url(), "osm/", var, "/", filename)
+		url <- .data_url(paste0("osm/", var, "/", filename))
+		if (is.null(url)) return(NULL)
 		if (!.downloadDirect(url, filepath, ...)) return(NULL)
 	} 
 	vect(filepath, proxy=proxy)
