@@ -1,7 +1,7 @@
 
 
 population <- function(year, res="5", path, ...) {
-	.check_path(path)
+	path <- .get_path(path)
 	stopifnot(as.numeric(year) %in% c(2000, 2005, 2010, 2015, 2020))
 	stopifnot(as.numeric(res) %in% c(10, 5, 2.5, 0.5))
 	res <- ifelse(res==0.5, "30s", paste0(res, "m"))
@@ -10,7 +10,9 @@ population <- function(year, res="5", path, ...) {
 	filepath <- file.path(path, "pop", filename)
 
 	if (!(file.exists(filepath))) {
-		url <- paste0(.data_url(), "pop/", filename)
+		url <- .data_url(paste0("pop/", filename))
+		if (is.null(url)) return(NULL)
+
 		dir.create(dirname(filepath), showWarnings=FALSE)
 		if (!.downloadDirect(url, filepath, ...)) return(NULL)
 	} 
