@@ -1,5 +1,4 @@
 
-.wcurl <- "https://geodata.ucdavis.edu/climate/worldclim/2_1/"
 
 .wccruts <- function(lon, lat, path, ...) {
 }
@@ -18,14 +17,15 @@
 }
 
 .wcerad <- function(lon, lat, path, ...) {
-	.check_path(path)
+	path <- .get_path(path)
 	id <- .get_id(lon, lat)	
 	pth <- file.path(path, "wcdera")
 	fname <- paste0("wcdera_", id, ".nc")
 	outfname <- file.path(pth, fname)
 	if (!file.exists(outfname)) {
 		dir.create(pth, showWarnings=FALSE)
-		turl <- paste0(.wcurl, "day/nc/", fname)
+		turl <- .wc_url(paste0("day/nc/", fname))
+		if (is.null(turl)) return(NULL)
 		if (!.downloadDirect(turl, outfname, ...)) return(NULL)
 	}
 	sds(outfname)
@@ -33,7 +33,7 @@
 
 
 .wcerad21 <- function(lon, lat, path, ...) {
-	.check_path(path)
+	path <- .get_path(path)
 	id <- .get_id(lon, lat)
 
 	pth <- file.path(path, "wcdera")
@@ -41,7 +41,9 @@
 	outfname <- file.path(pth, gsub("_", "21_", fname))
 	if (!file.exists(outfname)) {
 		dir.create(pth, showWarnings=FALSE)
-		turl <- paste0(.wcurl, "day/nc21/", fname)
+		turl <- .wc_url(paste0("day/nc21/", fname))
+		if (is.null(turl)) return(NULL)
+		
 		if (!.downloadDirect(turl, outfname, ...)) return(NULL)
 	}
 	sds(outfname)
@@ -54,7 +56,7 @@ worldclim_tile <- function(var, lon, lat, path, version="2.1", ...) {
 	version <- as.character(version)
 	stopifnot(version %in% c("2.1"))
 	if (var == "bioc") var <- "bio"
-	.check_path(path)
+	path <- .get_path(path)
 
 	r <- rast(res=30)
 	id <- cellFromXY(r, cbind(lon,lat))
@@ -67,7 +69,9 @@ worldclim_tile <- function(var, lon, lat, path, version="2.1", ...) {
 	outfname <- file.path(pth, fname)
 
 	if (!file.exists(outfname)) {
-		turl <- paste0(.wcurl, "tiles/tile/", fname)
+		turl <- .wc_url(paste0("tiles/tile/", fname))
+		if (is.null(turl)) return(NULL)
+	
 		if (!.downloadDirect(turl, outfname, ...)) return(NULL)
 	}
 	rast(outfname)
@@ -81,8 +85,8 @@ worldclim_country <- function(country, var, path, version="2.1", ...) {
 	stopifnot(version %in% c("2.1"))
 	if (var == "bioc") var <- "bio"
 	iso <- .getCountryISO(country)
-	
-	.check_path(path)
+
+	path <- .get_path(path)
 	pth <- file.path(path, "wc2.1_country")
 	dir.create(pth, showWarnings=FALSE)
 
@@ -90,7 +94,8 @@ worldclim_country <- function(country, var, path, version="2.1", ...) {
 	outfname <- file.path(pth, fname)
 	
 	if (!file.exists(outfname)) {
-		turl <- paste0(.wcurl, "tiles/iso/", fname)
+		turl <- .wc_url(paste0("tiles/iso/", fname))
+		if (is.null(turl)) return(NULL)
 		if (!.downloadDirect(turl, outfname, ...)) return(NULL)
 	}
 	rast(outfname)
@@ -105,7 +110,7 @@ worldclim_global <- function(var, res, path, version="2.1", ...) {
 	stopifnot(var %in% c("tavg", "tmin", "tmax", "prec", "bio", "bioc", "elev", "wind", "vapr", "srad"))
 	stopifnot(version %in% c("2.1"))
 	if (var == "bioc") var <- "bio"
-	.check_path(path)
+	path <- .get_path(path)
 
 	fres <- ifelse(res=="0.5", "30s", paste0(res, "m"))
 	path <- file.path(path, paste0("wc2.1_", fres, "/"))
@@ -121,7 +126,10 @@ worldclim_global <- function(var, res, path, version="2.1", ...) {
 	pzip <- file.path(path, zip)
 	ff <- file.path(path, ff)
 	if (!all(file.exists(ff))) {
-		if (!.downloadDirect(paste0(.wcurl, "base/", zip), pzip, ...)) return(NULL)
+		turl <- .wc_url(paste0("base/", zip))
+		if (is.null(turl)) return(NULL)
+
+		if (!.downloadDirect(turl, pzip, ...)) return(NULL)
 		fz <- try(utils::unzip(pzip, exdir=path), silent=TRUE)
 		try(file.remove(pzip), silent=TRUE)
 		if (inherits(fz, "try-error")) {
@@ -146,7 +154,7 @@ worldclim_global <- function(var, res, path, version="2.1", ...) {
 	# some combinations do not exist. Catch these here.
 	
 	if (var == "bio") var <- "bioc"
-	.check_path(path)
+	path <- .get_path(path)
 
 	fres <- ifelse(res==0.5, "30s", paste0(res, "m"))
 	path <- file.path(path, paste0("wc2.1_", fres, "/"))
@@ -156,7 +164,8 @@ worldclim_global <- function(var, res, path, version="2.1", ...) {
 	poutf <- file.path(path, outf)
 	if (!file.exists(poutf)) {
 		if (!file.exists(outf)) {
-			url <- paste0(.wcurl, "cmip6/", fres, "/", model, "/ssp", ssp, "/", outf)
+			url <- .wc_url(paste0("cmip6/", fres, "/", model, "/ssp", ssp, "/", outf))
+			if (is.null(url)) return(NULL)
 			if(!.downloadDirect(url, poutf, ...)) return(NULL)
 		}
 	}
@@ -205,7 +214,7 @@ cmip6_world <- function(model, ssp, time, var, res, path, ...) {
 	ssp <- as.character(ssp)
 	if (var == "bio") var <- "bioc"
 	try(.check_cmip6(res, var, ssp, model, time), silent=TRUE)
-	.check_path(path)
+	path <- .get_path(path)
 	path <- file.path(path, paste0("wc2.1_", fres, "/"))
 	dir.create(path, showWarnings=FALSE)
 	
@@ -228,7 +237,7 @@ cmip6_tile <- function(lon, lat, model, ssp, time, var, path, ...) {
 	ssp <- as.character(ssp)
 	if (var == "bio") var <- "bioc"
 	.check_cmip6(0.5, var, ssp, model, time)
-	.check_path(path)
+	path <- .get_path(path)
 	path <- file.path(path, paste0("wc2.1_30s/"))
 	dir.create(path, showWarnings=FALSE)
 
